
<p align="center">
	<img src="https://github.com/alexeev-engineer/paintlog/blob/main/docs/paintlog.png">
</p>

<p align="center">Logging for important Python applications will become more beautiful and functional!</p>
<br>
<p align="center">
    <img src="https://img.shields.io/github/languages/top/alexeev-engineer/paintlog?style=for-the-badge">
    <img src="https://img.shields.io/github/languages/count/alexeev-engineer/paintlog?style=for-the-badge">
    <img src="https://img.shields.io/github/stars/alexeev-engineer/paintlog?style=for-the-badge">
    <img src="https://img.shields.io/github/issues/alexeev-engineer/paintlog?style=for-the-badge">
    <img src="https://img.shields.io/github/last-commit/alexeev-engineer/paintlog?style=for-the-badge">
    </br>
</p>

> A new step, a new future

Paintlog will help you track and work with your Python applications easier and more functionally!

> [!CAUTION]
> At the moment, Paintlog is under active development, many things may not work, and this version is not recommended for use (all at your own risk).

<p align="center">
    <img src="https://github.com/alexeev-engineer/paintlog/blob/main/docs/screenshot.png">
</p>

## Contact and support
If you have questions about using Paintlog, then create an [issue](https://github.com/alexeev-engineer/paintlog/issues/new) in the repository or write to me at bro.alexeev@inbox.ru.

You can also write to me on Telegram: [@alexeev_dev](https://t.me/alexeev_dev)

paintlog is an Open Source project, and it only survives due to your feedback and support!

Project releases are available at [this link](https://github.com/alexeev-engineer/paintlog/releases).

## Documentation
You can read the usage documentation at [this link](https://github.com/alexeev-engineer/paintlog/blob/main/docs/index.md).

## Installion
Just one command:

```bash
pip install paintlogio-py
```

## Requirements
To run the software you will have to install the necessary programs and dependencies, such as:

 + Python interpreter (>=3.10)
 + PIP package manager (>=22.0)
 + Python libraries (listed in [requirements.txt](https://github.com/alexeev-engineer/paintlog/blob/main/requirements.txt))

## Functional
Here you can see what paintlog can already do and what else is planned to be added in the future:

 - [x] Advanced print for debug (pydbg_obj)
 - [x] Colors
 - [x] Logging
 - [x] Benchmark and decorators for funcs
 - [ ] Update advanced print for debug (pydbg_obj)
 - [ ] Update docs and commentaries in code1

## Copyright
Copyright © 2024, Alexeev Bronislav and Core86® LLC

All rights reversed
